Tutorials
=========

What follows are 7 pySOT tutorials that are based on a short course given at
CMWR 2016, Toronto. These notebooks are available at:
https://people.cam.cornell.edu/~dme65/talks.html


Tutorial 1: Hello World!
------------------------

.. include:: tutorial1.rst

Tutorial 2: Python objective function
-------------------------------------

.. include:: tutorial2.rst

Tutorial 3: MATLAB objective function
-------------------------------------

.. include:: tutorial3.rst

Tutorial 4: Python objective function with inequality constraints
-----------------------------------------------------------------

.. include:: tutorial4.rst

Tutorial 5: Equality constraints
--------------------------------

.. include:: tutorial5.rst

Tutorial 6: C++ objective function
----------------------------------

.. include:: tutorial6.rst